@@ -8,27 +8,9 @@
 # which accompanies this distribution, and is available at
 # http://opensource.org/licenses/cpl1.0.txt
 #
+package Devel::Ladybug::Error;
 
-=pod
-
-=head1 NAME
-
-Devel::Ladybug::Exceptions - Defines the exceptions which may be thrown
-inside of Devel::Ladybug
-
-=head1 EXCEPTION LIST
-
-See @__types in this package for the current list.
-
-XXX TODO: Automate the process of turning the exception list into docs.
-
-=head1 SEE ALSO
-
-L<Error>, L<Devel::Ladybug::Class>
-
-This file is part of L<Devel::Ladybug>.
-
-=cut
+use base qw| Error::Simple |;
 
 package Devel::Ladybug::Exceptions;
 
@@ -65,18 +47,37 @@ my @__types = qw|
   WrongHost
   |;
 
-our @types;
-
 for my $type (@__types) {
   my $class = sprintf( 'Devel::Ladybug::%s', $type );
 
-  eval qq|
-    package $class;
+  do {
+    no strict "refs";
 
-    use base qw/ Error::Simple /;
+    @{"$class\::ISA"} = "Devel::Ladybug::Error";
+  };
 
-    push @types, $class;
-  |;
 }
 
 1;
+__END__
+=pod
+
+=head1 NAME
+
+Devel::Ladybug::Exceptions - Defines the exceptions which may be thrown
+inside of Devel::Ladybug
+
+=head1 EXCEPTION LIST
+
+See @__types in this package for the current list.
+
+XXX TODO: Automate the process of turning the exception list into docs.
+
+=head1 SEE ALSO
+
+L<Error>, L<Devel::Ladybug::Class>
+
+This file is part of L<Devel::Ladybug>.
+
+=cut
+
